@@ -716,10 +716,11 @@ def _get_freeze_source_packages(
     return source_package_names
 
 
+@functools.lru_cache()
 def get_package_requirements(
     package_name: str,
     recursive: bool = True
-) -> Iterable[str]:
+) -> List[str]:
     # Get the output of `pip show`
     status: int
     output: str
@@ -728,6 +729,7 @@ def get_package_requirements(
         f'{sys.executable} -m pip show {package_name}'
     )
     required_package_names: Set[str] = set()
+    package_requirements: List[str] = []
     for line in output.split('\n'):
         if line.startswith('Requires:'):
             required_package_name: str
@@ -744,16 +746,19 @@ def get_package_requirements(
                             if required_package_depencency_name not in (
                                 required_package_names
                             ):
-                                yield required_package_depencency_name
+                                package_requirements.append(
+                                    required_package_depencency_name
+                                )
                                 required_package_names.add(
                                     required_package_depencency_name
                                 )
                     if required_package_name not in (
                         required_package_names
                     ):
-                        yield required_package_name
+                        package_requirements.append(required_package_name)
                         required_package_names.add(required_package_name)
             break
+    return package_requirements
 
 
 def _flatten_requirements(requirements: Iterable[str]) -> Iterable[str]:
